@@ -114,7 +114,7 @@ heatmaplyWelcomeMessage <- function() {
     "\n",
     "The github page is: https://github.com/talgalili/heatmaply/\n",
     "Please submit your suggestions and bug-reports at: https://github.com/talgalili/heatmaply/issues\n",
-    "Or contact: <tal.galili@gmail.com>\n",
+    "You may ask questions at stackoverflow, use the r and heatmaply tags: \n\t https://stackoverflow.com/questions/tagged/heatmaply\n",
     # "\n",
     # "\tTo suppress this message use:  ", "suppressPackageStartupMessages(library(heatmaply))\n",
     "======================\n"
@@ -250,7 +250,7 @@ heatmaplyWelcomeMessage <- function() {
 # # http://stackoverflow.com/questions/10330425/how-do-i-export-a-git-log-to-a-text-file
 # # http://stackoverflow.com/questions/3523534/good-ways-to-manage-a-changelog-using-git
 # # http://www.commandlinefu.com/commands/view/12420/generate-a-change-log-with-git
-# shell("git log --decorate > ChangeLog", intern = T)
+# shell("git log --decorate > ChangeLog", intern = TRUE)
 
 # Modify it using: http://git-scm.com/book/en/Git-Basics-Viewing-the-Commit-History
 #         http://stackoverflow.com/questions/9007181/custom-log-format-omits-newline-at-end-of-output
@@ -305,5 +305,6 @@ heatmaplyWelcomeMessage <- function() {
 # file.copy("NEWS", "NEWS.md",overwrite = TRUE)
 # devtools::check_win_devel()
 # pkgdown::build_home()
-# pkgdown::build_site(run_dont_run = TRUE)
+# pkgdown::build_site(run_dont_run = FALSE)
+# pkgdown::build_news()
 # release()
